==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/languages/pt_PT.php <==
<?php

return [
    'Names' => [
        'af' => 'africanês',
        'alt' => 'altai do sul',
        'ang' => 'inglês antigo',
        'arn' => 'mapuche',
        'ars' => 'árabe do Négede',
        'av' => 'avaric',
        'bax' => 'bamun',
        'bbj' => 'ghomala',
        'bn' => 'bengalês',
        'bua' => 'buriat',
        'ccp' => 'changma',
        'chk' => 'chuquês',
        'chn' => 'jargão chinook',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'co' => 'córsico',
        'crs' => 'francês crioulo seselwa',
        'cs' => 'checo',
        'cv' => 'chuvash',
        'efi' => 'efik',
        'egy' => 'egípcio clássico',
        'et' => 'estónio',
        'fon' => 'fon',
        'fro' => 'francês antigo',
        'frs' => 'frísio oriental',
        'fy' => 'frísico ocidental',
        'gez' => 'geʼez',
        'goh' => 'alemão alto antigo',
        'grc' => 'grego clássico',
        'gsw' => 'alemão suíço',
        'ha' => 'haúça',
        'hi' => 'hindi',
        'hy' => 'arménio',
        'kbd' => 'cabardiano',
        'kl' => 'gronelandês',
        'krc' => 'carachaio-bálcaro',
        'lez' => 'lezghiano',
        'lg' => 'ganda',
        'lou' => 'crioulo de Louisiana',
        'lrc' => 'luri do norte',
        'mak' => 'makassarês',
        'mfe' => 'crioulo mauriciano',
        'mk' => 'macedónio',
        'moh' => 'mohawk',
        'mr' => 'marata',
        'nb' => 'norueguês bokmål',
        'nds' => 'baixo-alemão',
        'nl' => 'neerlandês',
        'nn' => 'norueguês nynorsk',
        'non' => 'nórdico antigo',
        'oc' => 'occitano',
        'os' => 'ossético',
        'pag' => 'língua pangasinesa',
        'pam' => 'pampango',
        'peo' => 'persa antigo',
        'pl' => 'polaco',
        'pon' => 'língua pohnpeica',
        'pro' => 'provençal antigo',
        'ps' => 'pastó',
        'raj' => 'rajastanês',
        'rhg' => 'rohingya',
        'se' => 'sami do norte',
        'sga' => 'irlandês antigo',
        'shu' => 'árabe do Chade',
        'sma' => 'sami do sul',
        'smn' => 'inari sami',
        'sn' => 'shona',
        'st' => 'sesoto',
        'te' => 'telugu',
        'tem' => 'temne',
        'tg' => 'tajique',
        'tk' => 'turcomano',
        'to' => 'tonga',
        'tt' => 'tatar',
        'tzm' => 'tamazigue do Atlas Central',
        'uz' => 'usbeque',
        'wo' => 'uólofe',
        'xh' => 'xosa',
        'xog' => 'soga',
        'yo' => 'ioruba',
        'zgh' => 'tamazight marroquino padrão',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'árabe moderno padrão',
        'de_AT' => 'alemão austríaco',
        'de_CH' => 'alto alemão suíço',
        'en_AU' => 'inglês australiano',
        'en_CA' => 'inglês canadiano',
        'en_GB' => 'inglês britânico',
        'en_US' => 'inglês americano',
        'es_419' => 'espanhol latino-americano',
        'es_ES' => 'espanhol europeu',
        'es_MX' => 'espanhol mexicano',
        'fa_AF' => 'dari',
        'fr_CA' => 'francês canadiano',
        'fr_CH' => 'francês suíço',
        'nds_NL' => 'baixo-saxão',
        'nl_BE' => 'flamengo',
        'pt_BR' => 'português do Brasil',
        'pt_PT' => 'português europeu',
        'ro_MD' => 'moldávio',
        'zh_Hans' => 'chinês simplificado',
        'zh_Hant' => 'chinês tradicional',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/languages/pt_PT.php <==
<?php

return [
    'Names' => [
        'af' => 'africanês',
        'alt' => 'altai do sul',
        'ang' => 'inglês antigo',
        'arn' => 'mapuche',
        'ars' => 'árabe do Négede',
        'av' => 'avar',
        'bax' => 'bamun',
        'bbj' => 'ghomala',
        'bn' => 'bengalês',
        'bua' => 'buriat',
        'ccp' => 'changma',
        'chk' => 'chuquês',
        'chn' => 'jargão chinook',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'co' => 'córsico',
        'crr' => 'algonquiano de Carolina',
        'crs' => 'francês crioulo seselwa',
        'cs' => 'checo',
        'cv' => 'chuvash',
        'efi' => 'efik',
        'egy' => 'egípcio clássico',
        'et' => 'estónio',
        'fon' => 'fon',
        'fro' => 'francês antigo',
        'frs' => 'frísio oriental',
        'fy' => 'frísico ocidental',
        'gez' => 'geʼez',
        'goh' => 'alemão alto antigo',
        'grc' => 'grego clássico',
        'gsw' => 'alemão suíço',
        'ha' => 'haúça',
        'hi' => 'hindi',
        'hy' => 'arménio',
        'ikt' => 'inuktitut canadiano ocidental',
        'kbd' => 'cabardiano',
        'kl' => 'gronelandês',
        'krc' => 'carachaio-bálcaro',
        'lez' => 'lezghiano',
        'lg' => 'ganda',
        'lou' => 'crioulo de Louisiana',
        'lrc' => 'luri do norte',
        'lus' => 'mizo',
        'mak' => 'makassarês',
        'mfe' => 'crioulo mauriciano',
        'mk' => 'macedónio',
        'moh' => 'mohawk',
        'mr' => 'marata',
        'nb' => 'norueguês bokmål',
        'nds' => 'baixo-alemão',
        'nl' => 'neerlandês',
        'nn' => 'norueguês nynorsk',
        'non' => 'nórdico antigo',
        'oc' => 'occitano',
        'os' => 'ossético',
        'pag' => 'língua pangasinesa',
        'pam' => 'pampango',
        'peo' => 'persa antigo',
        'pl' => 'polaco',
        'pon' => 'língua pohnpeica',
        'pro' => 'provençal antigo',
        'ps' => 'pastó',
        'raj' => 'rajastanês',
        'rhg' => 'rohingya',
        'se' => 'sami do norte',
        'sga' => 'irlandês antigo',
        'shu' => 'árabe do Chade',
        'sma' => 'sami do sul',
        'smn' => 'inari sami',
        'sn' => 'shona',
        'st' => 'sesoto',
        'str' => 'salish dos estreitos',
        'te' => 'telugu',
        'tem' => 'temne',
        'tg' => 'tajique',
        'tk' => 'turcomano',
        'to' => 'tonga',
        'tt' => 'tatar',
        'ttm' => 'tutchone do norte',
        'tzm' => 'tamazigue do Atlas Central',
        'uz' => 'usbeque',
        'wo' => 'uólofe',
        'xh' => 'xosa',
        'xog' => 'soga',
        'yo' => 'ioruba',
        'zgh' => 'tamazight marroquino padrão',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'árabe moderno padrão',
        'de_AT' => 'alemão austríaco',
        'de_CH' => 'alto alemão suíço',
        'en_AU' => 'inglês australiano',
        'en_CA' => 'inglês canadiano',
        'en_GB' => 'inglês britânico',
        'en_US' => 'inglês americano',
        'es_419' => 'espanhol latino-americano',
        'es_ES' => 'espanhol europeu',
        'es_MX' => 'espanhol mexicano',
        'fr_CA' => 'francês canadiano',
        'fr_CH' => 'francês suíço',
        'nds_NL' => 'baixo-saxão',
        'pt_BR' => 'português do Brasil',
        'pt_PT' => 'português europeu',
    ],
];
